==> ec2-1.0.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/CfnVPNGatewayRoutePropagationProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::VPNGatewayRoutePropagation`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpn-gatewayrouteprop.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.0 (build a586a1a)", date = "2019-07-11T14:13:21.658Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnVPNGatewayRoutePropagationProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::EC2::VPNGatewayRoutePropagation.RouteTableIds`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpn-gatewayrouteprop.html#cfn-ec2-vpngatewayrouteprop-routetableids
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.util.List<java.lang.String> getRouteTableIds();
    /**
     * `AWS::EC2::VPNGatewayRoutePropagation.VpnGatewayId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpn-gatewayrouteprop.html#cfn-ec2-vpngatewayrouteprop-vpngatewayid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getVpnGatewayId();

    /**
     * @return a {@link Builder} of {@link CfnVPNGatewayRoutePropagationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnVPNGatewayRoutePropagationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Builder {
        private java.util.List<java.lang.String> _routeTableIds;
        private java.lang.String _vpnGatewayId;

        /**
         * Sets the value of RouteTableIds
         * @param value `AWS::EC2::VPNGatewayRoutePropagation.RouteTableIds`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withRouteTableIds(final java.util.List<java.lang.String> value) {
            this._routeTableIds = java.util.Objects.requireNonNull(value, "routeTableIds is required");
            return this;
        }
        /**
         * Sets the value of VpnGatewayId
         * @param value `AWS::EC2::VPNGatewayRoutePropagation.VpnGatewayId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withVpnGatewayId(final java.lang.String value) {
            this._vpnGatewayId = java.util.Objects.requireNonNull(value, "vpnGatewayId is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnVPNGatewayRoutePropagationProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public CfnVPNGatewayRoutePropagationProps build() {
            return new CfnVPNGatewayRoutePropagationProps() {
                private final java.util.List<java.lang.String> $routeTableIds = java.util.Objects.requireNonNull(_routeTableIds, "routeTableIds is required");
                private final java.lang.String $vpnGatewayId = java.util.Objects.requireNonNull(_vpnGatewayId, "vpnGatewayId is required");

                @Override
                public java.util.List<java.lang.String> getRouteTableIds() {
                    return this.$routeTableIds;
                }

                @Override
                public java.lang.String getVpnGatewayId() {
                    return this.$vpnGatewayId;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("routeTableIds", om.valueToTree(this.getRouteTableIds()));
                    obj.set("vpnGatewayId", om.valueToTree(this.getVpnGatewayId()));
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.CfnVPNGatewayRoutePropagationProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::EC2::VPNGatewayRoutePropagation.RouteTableIds`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpn-gatewayrouteprop.html#cfn-ec2-vpngatewayrouteprop-routetableids
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.util.List<java.lang.String> getRouteTableIds() {
            return this.jsiiGet("routeTableIds", java.util.List.class);
        }

        /**
         * `AWS::EC2::VPNGatewayRoutePropagation.VpnGatewayId`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpn-gatewayrouteprop.html#cfn-ec2-vpngatewayrouteprop-vpngatewayid
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getVpnGatewayId() {
            return this.jsiiGet("vpnGatewayId", java.lang.String.class);
        }
    }
}

==> ec2-1.1.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/CfnVPNGatewayRoutePropagationProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::VPNGatewayRoutePropagation`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpn-gatewayrouteprop.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.2 (build e881f16)", date = "2019-07-19T19:06:47.586Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnVPNGatewayRoutePropagationProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::EC2::VPNGatewayRoutePropagation.RouteTableIds`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpn-gatewayrouteprop.html#cfn-ec2-vpngatewayrouteprop-routetableids
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.util.List<java.lang.String> getRouteTableIds();
    /**
     * `AWS::EC2::VPNGatewayRoutePropagation.VpnGatewayId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpn-gatewayrouteprop.html#cfn-ec2-vpngatewayrouteprop-vpngatewayid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getVpnGatewayId();

    /**
     * @return a {@link Builder} of {@link CfnVPNGatewayRoutePropagationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnVPNGatewayRoutePropagationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Builder {
        private java.util.List<java.lang.String> _routeTableIds;
        private java.lang.String _vpnGatewayId;

        /**
         * Sets the value of RouteTableIds
         * @param value `AWS::EC2::VPNGatewayRoutePropagation.RouteTableIds`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withRouteTableIds(final java.util.List<java.lang.String> value) {
            this._routeTableIds = java.util.Objects.requireNonNull(value, "routeTableIds is required");
            return this;
        }
        /**
         * Sets the value of VpnGatewayId
         * @param value `AWS::EC2::VPNGatewayRoutePropagation.VpnGatewayId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withVpnGatewayId(final java.lang.String value) {
            this._vpnGatewayId = java.util.Objects.requireNonNull(value, "vpnGatewayId is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnVPNGatewayRoutePropagationProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnVPNGatewayRoutePropagationProps build() {
            return new CfnVPNGatewayRoutePropagationProps() {
                private final java.util.List<java.lang.String> $routeTableIds = java.util.Objects.requireNonNull(_routeTableIds, "routeTableIds is required");
                private final java.lang.String $vpnGatewayId = java.util.Objects.requireNonNull(_vpnGatewayId, "vpnGatewayId is required");

                @Override
                public java.util.List<java.lang.String> getRouteTableIds() {
                    return this.$routeTableIds;
                }

                @Override
                public java.lang.String getVpnGatewayId() {
                    return this.$vpnGatewayId;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("routeTableIds", om.valueToTree(this.getRouteTableIds()));
                    obj.set("vpnGatewayId", om.valueToTree(this.getVpnGatewayId()));
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.CfnVPNGatewayRoutePropagationProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::EC2::VPNGatewayRoutePropagation.RouteTableIds`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpn-gatewayrouteprop.html#cfn-ec2-vpngatewayrouteprop-routetableids
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public java.util.List<java.lang.String> getRouteTableIds() {
            return this.jsiiGet("routeTableIds", java.util.List.class);
        }

        /**
         * `AWS::EC2::VPNGatewayRoutePropagation.VpnGatewayId`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpn-gatewayrouteprop.html#cfn-ec2-vpngatewayrouteprop-vpngatewayid
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public java.lang.String getVpnGatewayId() {
            return this.jsiiGet("vpnGatewayId", java.lang.String.class);
        }
    }
}
